@@ -1,22 +1,19 @@
 from ape import plugins
 
-from .providers import Infura
+from .provider import Infura
 
 NETWORKS = {
     "ethereum": [
         "mainnet",
-        "ropsten",
-        "rinkeby",
-        "kovan",
         "goerli",
+        "sepolia",
     ],
     "arbitrum": [
         "mainnet",
-        "testnet",
+        "goerli",
     ],
     "optimism": [
         "mainnet",
-        "kovan",
         "goerli",
     ],
     "polygon": [
